package ch.nextbet.exceptionmapper;

import java.io.Serializable;
import java.util.List;
import java.util.stream.Collectors;

import javax.validation.ConstraintViolationException;
import javax.validation.Path;
import javax.ws.rs.core.Response;
import javax.ws.rs.ext.ExceptionMapper;
import javax.ws.rs.ext.Provider;

import com.fasterxml.jackson.annotation.JsonAutoDetect;
import com.fasterxml.jackson.annotation.JsonAutoDetect.Visibility;

@Provider
public class ConstraintViolationExceptionMapper implements ExceptionMapper<ConstraintViolationException> {

	@Override
	public Response toResponse(ConstraintViolationException exception) {
		return Response.status(400).entity(new ExceptionWrapper(exception)).build();
	}

	@JsonAutoDetect(fieldVisibility = Visibility.ANY, getterVisibility = Visibility.NONE, setterVisibility = Visibility.NONE)
	public static class ExceptionWrapper implements Serializable {
		private static final long serialVersionUID = -4617884193517069833L;
		public List<ConstraintViolation> validations;

		public ExceptionWrapper(ConstraintViolationException exception) {
			validations = exception.getConstraintViolations().stream().map(cv -> new ConstraintViolation(cv.getPropertyPath(), cv.getMessage())).collect(Collectors.toList());
		}
	}

	public static class ConstraintViolation implements Serializable {

		private static final long serialVersionUID = 5716003820918620640L;

		public String item;
		public String message;

		public ConstraintViolation(Path item, String message) {
			this.item = item.toString();
			this.message = message;
		}
	}
}