package ch.nextbet.repository;

import java.util.List;

import javax.enterprise.context.RequestScoped;
import javax.transaction.Transactional;

import com.blazebit.persistence.CriteriaBuilder;
import com.blazebit.persistence.view.EntityViewSetting;

import ch.nextbet.domain.Better;
import ch.nextbet.view.BetterView;
import ch.nextbet.view.RankingView;

@RequestScoped
public class BetterRepository extends BaseRepository {

	public List<BetterView> getForPerson(String userName) {
		CriteriaBuilder<Better> cb = criteriaBuilder.create(entityManager, Better.class);
		CriteriaBuilder<BetterView> cbView = viewManager.applySetting(EntityViewSetting.create(BetterView.class), cb);

		return cbView.where("subject").eq(userName).getResultList();
	}

	public BetterView getForPersonAndTournament(Long tournamentId, String userName) {
		CriteriaBuilder<Better> cb = criteriaBuilder.create(entityManager, Better.class);
		CriteriaBuilder<BetterView> cbView = viewManager.applySetting(EntityViewSetting.create(BetterView.class), cb);

		return cbView.where("subject").eq(userName).where("tournament.id").eq(tournamentId).getSingleResult();
	}

	@Transactional
	public void save(Better better) {
		entityManager.persist(better);
	}

	public List<RankingView> getRanking(Long tournamentId) {
		CriteriaBuilder<Better> cb = criteriaBuilder.create(entityManager, Better.class);
		CriteriaBuilder<RankingView> cbView = viewManager.applySetting(EntityViewSetting.create(RankingView.class), cb);

		return cbView.where("tournament.id").eq(tournamentId).orderBy("rank", true).getResultList();
	}
}