package ch.nextbet;

import java.io.InputStream;
import java.security.KeyFactory;
import java.security.PrivateKey;
import java.security.spec.PKCS8EncodedKeySpec;
import java.util.Base64;

import org.eclipse.microprofile.jwt.Claims;

import io.smallrye.jwt.build.Jwt;
import io.smallrye.jwt.build.JwtClaimsBuilder;

public class TokenUtils {

	private TokenUtils() {
		// no-op: utility class
	}

	public static String generateToken(String subject) throws Exception {
		JwtClaimsBuilder claims = Jwt.claims("/token.json");

		claims.subject(subject);

		long currentTimeInSecs = currentTimeInSecs();
		long exp = currentTimeInSecs + 300;
		claims.issuedAt(currentTimeInSecs);
		claims.claim(Claims.auth_time.name(), currentTimeInSecs);
		claims.expiresAt(exp);

		return claims.jws().sign(readPrivateKey("/privateKey.pem"));
	}

	public static PrivateKey readPrivateKey(String pemResName) throws Exception {
		try (InputStream contentIS = TokenUtils.class.getResourceAsStream(pemResName)) {
			byte[] tmp = new byte[4096];
			int length = contentIS.read(tmp);
			return decodePrivateKey(new String(tmp, 0, length, "UTF-8"));
		}
	}

	public static PrivateKey decodePrivateKey(String pemEncoded) throws Exception {
		byte[] encodedBytes = Base64.getDecoder().decode(pemEncoded);

		PKCS8EncodedKeySpec keySpec = new PKCS8EncodedKeySpec(encodedBytes);
		KeyFactory kf = KeyFactory.getInstance("RSA");
		return kf.generatePrivate(keySpec);
	}

	public static int currentTimeInSecs() {
		long currentTimeMS = System.currentTimeMillis();
		return (int) (currentTimeMS / 1000);
	}
}