package ch.nextbet.resource;

import static io.restassured.RestAssured.given;
import static org.hamcrest.core.Is.is;

import org.junit.jupiter.api.MethodOrderer.OrderAnnotation;
import org.junit.jupiter.api.Order;
import org.junit.jupiter.api.Test;
import org.junit.jupiter.api.TestMethodOrder;

import ch.nextbet.TokenUtils;
import io.quarkus.test.junit.QuarkusTest;
import io.restassured.http.ContentType;
import io.restassured.response.Response;

@QuarkusTest
@TestMethodOrder(OrderAnnotation.class)
public class BetterResourceTest {

	@Test
	@Order(1)
	public void testNoBetterAvailable() throws Exception {
		String token = TokenUtils.generateToken("uex5337");
		Response response = given().auth().oauth2(token).get("/better").andReturn();
		response.then().statusCode(200).assertThat().body("size()", is(0));
	}

	@Test
	@Order(2)
	public void testGetExistingBetter() throws Exception {
		String token = TokenUtils.generateToken("tkp0i");
		Response response = given().auth().oauth2(token).get("/better").andReturn();
		response.then().statusCode(200).assertThat().body("size()", is(2));
	}

	@Test
	@Order(3)
	public void testAddBetterToPerson() throws Exception {
		String token = TokenUtils.generateToken("upr1860");
		Response response = given().contentType(ContentType.JSON).auth().oauth2(token).body("11002").post("/better").andReturn();
		response.then().statusCode(202).body("tournamentId", is(11002));
	}

	@Test
	@Order(4)
	public void testNoAuth() {
		Response response = given().get("/better").andReturn();
		response.then().statusCode(401);
	}
}